Contradiction and supersession detection. Contradiction and cycle detection in the knowledge graph.
Functions
- detect_
cycles - Detect cycles in the graph considering only the specified edge types. Returns a list of cycles, each represented as a vector of node IDs.
- find_
contradictions - Find all nodes that contradict
id, including transitive contradictions through Supports->Contradicts chains. - find_
superseded - Find all nodes superseded by
id(directly or transitively).